#
# spec file for package python-pykeepass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pykeepass
Version:        4.1.0.post1
Release:        1.2
Summary:        Low-level library to interact with keepass databases
License:        GPL-3.0-only
URL:            https://github.com/libkeepass/pykeepass
Source:         https://github.com/libkeepass/pykeepass/archive/refs/tags/v%{version}.tar.gz#/pykeepass-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyotp}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-argon2-cffi >= 20.1.0
Requires:       python-construct >= 2.10.54
Requires:       python-lxml >= 4.6.1
Requires:       python-pycryptodomex >= 3.10.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module argon2-cffi >= 20.1.0}
BuildRequires:  %{python_module construct >= 2.10.54}
BuildRequires:  %{python_module lxml >= 4.6.1}
BuildRequires:  %{python_module pycryptodomex >= 3.10.1}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This library allows you to write entries to a KeePass database

%prep
%autosetup -p1 -n pykeepass-%{version}
sed -i '1{/^#!.*env python/d}' pykeepass/{pykeepass,deprecated,kdbx_parsing/kdbx*}.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand export PYTHONPATH=%{buildroot}%{python3_sitelib}
export PYTHONDONTWRITEBYTECODE=1
%python_exec tests/tests.py

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/pykeepass/
%{python_sitelib}/pykeepass-%{version}.dist-info/

%changelog
* Fri Aug  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.1.0.post1:
  * [gh#libkeepass/pykeepass#389] add PyKeePassdatabase_name and
    database_description
  * [gh#libkeepass/pykeepass#390] fix pkg_resources dependency
    issue
  * [gh#libkeepass/pykeepass#391] Entry.tags returns empty list
    instead of None
  * [gh#libkeepass/pykeepass#395] set 'encoding' attribute when
    exporting as XML
  * [gh#libkeepass/pykeepass#383] parse datetimes using isoformat
    instead of strptime
* Sun Apr 14 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.7.post1:
  * Fix gnome secrets crashes on expiration date check with
    missmatch of date format (gh#libkeepass/pykeepass#382).
  * Fix missing pykeepass.kdbx_parsing when built with modern
    tools (gh#libkeepass/pykeepass#378).
  * Remove shebang line from pykeepass/deprecated.py
    (gh#libkeepass/pykeepass#377).
- Drop fix-upstream-test-case.patch: upstream committed.
* Wed Mar 27 2024 Richard Rahl <rrahl0@proton.me>
- Update to 4.0.7:
  * PyKeePass has decrypt kwarg for accessing header info
  * added Entry.index and Entry.move for moving entries
  * added Entry.autotype_window setter
  * allow filename/keyfile to be file-like objects
  * drop dateutil dependency
  * switch to pyproject.toml
- add fix-upstream-test-case.patch for fixing an issue with
  missing pykeepass.kdbx_parsing
* Tue Sep  5 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.0.6:
  * fixed #350 - fixed all Python 2 deprecation FIXMEs (e.g. future, )
- Switch to pyproject macros.
* Sat Jun 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.5:
  * [gh#libkeepass/pykeepass#344] AttributeError when accessing
    Times with None value
  * use __hash__ when evaluating equality
  * use mtime/uuid for HistoryEntry hashing
* Sun May 28 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.4:
  * [gh#libkeepass/pykeepass#314] correctly handle binaries with
    no data.
  * [gh#libkeepass/pykeepass#265] check for keepass signature.
  * [gh#libkeepass/pykeepass#319] support pathlib for
    filename/keyfile.
  * [gh#libkeepass/pykeepass#194] added 'protected' arg to
    _set_string_field.
  * [gh#libkeepass/pykeepass#338] allow comma entry tag separator.
  * use official icon names from KeePass source and deprecate old
    icons.
  * added Entry.is_custom_property_protected().
* Tue Jun 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.3:
  * Add otp support.
  * Add debug_setup() function.
* Sun May 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.2:
  * Added support for argon2id key derivation function.
  * Added credential expiry functions.
  * Fixes gh#libkeepass/pykeepass#223 - safe saving.
* Sun May 23 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.1:
  * No release notes.
- Drop python-pykeepass-fix-version.patch: incorporated upstream.
- Update dependency versions in keeping with upstream.
* Mon Feb 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.0:
  * Paths changed from strings to lists.
  * Added PyKeePass.recyclebin_group.
  * Added PyKeePass.trash_group().
  * Added PyKeePass.trash_entry().
  * Added PyKeePass.empty_group().
  * Support reading/saving from streams.
  * Fixed PyKeePass.dump_xml() pretty printing.
  * Fixed gh#libkeepass/pykeepass#212 - properly pad encrypted
    payload.
  * Fixed gh#libkeepass/pykeepass#222 - corrected transform_rounds
    field length.
- Add python-pykeepass-fix-version.patch: Fix version so that
  egg-infos don't end up with the wrong version; patch taken from
  upstream commit.
- Update URL and Source URL to new github repository.
* Sat Aug  1 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.1:
  * Pin construct version to last supporting python2
  * Hard dependency on pycryptodomex
  * Fixed kp.groups, kp.entries not returning elements with
    name/title None [gh#libkeepass/pykeepass#193].
- Replace pycryptodome in BuildRequires and Requires, with
  pycryptodomex.
- Update version of python-construct in BuildRequires and
  Requires.
- Update %%check section to run tests directly as recommended by
  upstream.
* Tue Apr 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.2.0:
  * Added PyKeePass.xml().
  * Added create_database().
  * Added tag searching - gh#libkeepass/pykeepass#182.
  * Binary attachments missing Compressed attribute unparseable
    [gh#libkeepass/pykeepass#181].
  * Protected multiline fields missing newline
    [gh#libkeepass/pykeepass#129].
  * Fixed problem where entries are protected after save.
- Changes from version 3.1.0:
  * Removed context manager.
  * Added autotype string support.
  * Added attachments.
  * Fixed find_entries(path=xxx) behavior.
  * Entry.uuid, Group.uuid now return uuid.UUID object instead of
    string.
* Tue Apr  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix argon2_cffi -> argon2-cffi dependency name
* Tue Mar 19 2019 John Vandenberg <jayvdb@gmail.com>
- Add minimum version python-construct >= 2.9.31
* Tue Mar 19 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite on Python 3 using GitHub archive.
  Currently failing on Python 2
- Add missing runtime dependencies
- Add %%license
- Update to v3.0.3
  * Python 3.7 support
  * Autotype support
  * Fix "object has no attribute" issue in save_history
  * Fix datetime comparison when there is no tzinfo and autotype sequence
  * Added new Attachment object (see README.rst for usage)
  * Moved the xpath strings into xpath.py
  * Added exceptions.py
  * Fix entry.parentgroup doesn't work for history entries
  * Move first and history into _xpath
  * Use UUID instead of (name, title, password, ...) when comparing objects
  * Notes is a reserved key
* Wed Sep 12 2018 badshah400@gmail.com
- Update to version 3.0.2:
  * Exclude tests from pypi package.
- Changes from version 3.0.1:
  * Fix installation (gh#pschmitt/pykeepass#98).
- Changes from version 3.0.0:
  * Update lxml from 4.2.1 to 4.2.3 (gh#pschmitt/pykeepass#86).
  * KDBX4 support (gh#pschmitt/pykeepass#84).
  * Update argon2-cffi from 18.1.0 to 18.3.0
    (gh#pschmitt/pykeepass#92).
  * Update pycryptodome from 3.6.3 to 3.6.6
    (gh#pschmitt/pykeepass#91).
  * Fix baseelement logic (gh#pschmitt/pykeepass#94).
  * Make pykeepass usable as a context manager
    (gh#pschmitt/pykeepass#87).
  * Strip out non-ASCII characters on decrypt
    (gh#pschmitt/pykeepass#97).
- Drop dependency on python-libkeepass, python-pykeepass no longer
  requires this since version 3.0.0; python-libkeepass is now
  deprecated.
- Recompile .pyc files from sources modified after install script
  to prevent inconsistent mtimes between object files and sources.
* Wed Aug 22 2018 badshah400@gmail.com
- Initial package.
